latent <- function(k = 2, z.delta = 0.1, z.prior.mu = 0,
                   z.prior.sd = 10, b.delta = 0.5, b.prior.mu = 0, 
                   b.prior.sd = 10){
    cat("The central function in the 'latentnet' package is 'ergmm'\n")
    cat('Type help(package="latentnet") to get started.\n')
}
latentcluster <- function(k=2, ngroups, z.prior.mu=0, z.prior.sd=10,
               b.delta=0.5, b.prior.mu=0, b.prior.sd=10,
               Sigprior = qchisq(0.05,3),
               muSigprior = 2, dirprior=3,
               alphaprior=3,
               chisqprop = 6, thetaprop=0.1, ...){
    cat("The central function in the 'latentnet' package is 'ergmm'\n")
    cat('Type help(package="latentnet") to get started.\n')
}
